@@ -27,6 +27,9 @@ All contributions are celebrated.
 
 Licensed under [Apache 2.0](./LICENSE).
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -41,7 +44,7 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.data_type(
@@ -57,10 +60,10 @@ class BuildArg:
         :param value: the value of the build arg.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(BuildArg.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ca90ca8d86c9ed6ff2939da564863cfb5e38c881063bf920a7acba369d4f61e0)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
             "value": value,
         }
@@ -92,7 +95,7 @@ class BuildArg:
 
 
 class Image(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk8s-image.Image",
 ):
@@ -106,11 +109,11 @@ class Image(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         dir: builtins.str,
-        build_args: typing.Optional[typing.Sequence[typing.Union[BuildArg, typing.Dict[str, typing.Any]]]] = None,
+        build_args: typing.Optional[typing.Sequence[typing.Union[BuildArg, typing.Dict[builtins.str, typing.Any]]]] = None,
         file: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
         platform: typing.Optional[builtins.str] = None,
@@ -129,7 +132,7 @@ class Image(
         :param tag: Tag for the image. Docker convention is {registry_name}/{name}:{tag} Visit https://docs.docker.com/engine/reference/commandline/tag/ for more information Default: "latest"
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Image.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__a844f8e37776c3b54ec8ae40647549dc3d93a4f8fcb5ffcc8b0c270362b96bed)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ImageProps(
@@ -144,7 +147,7 @@ class Image(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="url")
     def url(self) -> builtins.str:
         '''The image URL to use in order to pull this instance of the image.'''
@@ -169,7 +172,7 @@ class ImageProps:
         self,
         *,
         dir: builtins.str,
-        build_args: typing.Optional[typing.Sequence[typing.Union[BuildArg, typing.Dict[str, typing.Any]]]] = None,
+        build_args: typing.Optional[typing.Sequence[typing.Union[BuildArg, typing.Dict[builtins.str, typing.Any]]]] = None,
         file: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
         platform: typing.Optional[builtins.str] = None,
@@ -187,7 +190,7 @@ class ImageProps:
         :param tag: Tag for the image. Docker convention is {registry_name}/{name}:{tag} Visit https://docs.docker.com/engine/reference/commandline/tag/ for more information Default: "latest"
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ImageProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__1564f5ed59dc0c051b02fd845baca12c50c7bd102fa2de012e50ea8be1758009)
             check_type(argname="argument dir", value=dir, expected_type=type_hints["dir"])
             check_type(argname="argument build_args", value=build_args, expected_type=type_hints["build_args"])
             check_type(argname="argument file", value=file, expected_type=type_hints["file"])
@@ -195,7 +198,7 @@ class ImageProps:
             check_type(argname="argument platform", value=platform, expected_type=type_hints["platform"])
             check_type(argname="argument registry", value=registry, expected_type=type_hints["registry"])
             check_type(argname="argument tag", value=tag, expected_type=type_hints["tag"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "dir": dir,
         }
         if build_args is not None:
@@ -292,3 +295,39 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__ca90ca8d86c9ed6ff2939da564863cfb5e38c881063bf920a7acba369d4f61e0(
+    *,
+    name: builtins.str,
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a844f8e37776c3b54ec8ae40647549dc3d93a4f8fcb5ffcc8b0c270362b96bed(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    dir: builtins.str,
+    build_args: typing.Optional[typing.Sequence[typing.Union[BuildArg, typing.Dict[builtins.str, typing.Any]]]] = None,
+    file: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    platform: typing.Optional[builtins.str] = None,
+    registry: typing.Optional[builtins.str] = None,
+    tag: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1564f5ed59dc0c051b02fd845baca12c50c7bd102fa2de012e50ea8be1758009(
+    *,
+    dir: builtins.str,
+    build_args: typing.Optional[typing.Sequence[typing.Union[BuildArg, typing.Dict[builtins.str, typing.Any]]]] = None,
+    file: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    platform: typing.Optional[builtins.str] = None,
+    registry: typing.Optional[builtins.str] = None,
+    tag: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
