@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -14,7 +17,7 @@ import cdk8s._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk8s-image", "0.2.538", __name__[0:-6], "cdk8s-image@0.2.538.jsii.tgz"
+    "cdk8s-image", "0.2.629", __name__[0:-6], "cdk8s-image@0.2.629.jsii.tgz"
 )
 
 __all__ = [
